@@ -178,7 +178,10 @@ template_mmrm_tables <- function(parentname,
   y <- list()
   ref_arm_val <- paste(ref_arm, collapse = "/")
 
-  all_basic_table_args <- teal.widgets::resolve_basic_table_args(basic_table_args)
+  all_basic_table_args <- teal.widgets::resolve_basic_table_args(
+    basic_table_args,
+    module_table = teal.widgets::basic_table_args(show_colcounts = !is.null(arm_var))
+  )
 
   # Build layout.
   layout_list <- list()
@@ -202,8 +205,7 @@ template_mmrm_tables <- function(parentname,
       layout_list <- add_expr(
         layout_list,
         substitute(
-          expr = rtables::add_colcounts() %>%
-            rtables::split_rows_by(visit_var) %>%
+          expr = rtables::split_rows_by(visit_var) %>%
             append_varlabels(dataname, visit_var) %>%
             tern.mmrm::summarize_lsmeans(
               .stats = c(
@@ -227,8 +229,7 @@ template_mmrm_tables <- function(parentname,
       layout_list <- add_expr(
         layout_list,
         substitute(
-          expr = rtables::add_colcounts() %>%
-            rtables::split_rows_by(visit_var) %>%
+          expr = rtables::split_rows_by(visit_var) %>%
             append_varlabels(dataname, visit_var) %>%
             tern.mmrm::summarize_lsmeans(show_relative = show_relative) %>%
             rtables::append_topleft(paste0("  ", paramcd)),
@@ -272,7 +273,6 @@ template_mmrm_tables <- function(parentname,
             df = df_explicit_na(broom::tidy(fit_mmrm), na_level = default_na_str()),
             alt_counts_df = parentname
           )
-          lsmeans_table
         },
         env = list(
           parentname = as.name(parentname),
@@ -283,9 +283,8 @@ template_mmrm_tables <- function(parentname,
     t_mmrm_cov = {
       y$cov_matrix <- substitute(
         expr = {
-          cov_matrix <- tern.mmrm::as.rtable(fit_mmrm, type = "cov")
-          subtitles(cov_matrix) <- st
-          cov_matrix
+          covariance_table <- tern.mmrm::as.rtable(fit_mmrm, type = "cov")
+          subtitles(covariance_table) <- st
         },
         env = list(
           fit_mmrm = as.name(fit_name),
@@ -296,9 +295,8 @@ template_mmrm_tables <- function(parentname,
     t_mmrm_fixed = {
       y$fixed_effects <- substitute(
         expr = {
-          fixed_effects <- tern.mmrm::as.rtable(fit_mmrm, type = "fixed")
-          subtitles(fixed_effects) <- st
-          fixed_effects
+          fixed_effects_table <- tern.mmrm::as.rtable(fit_mmrm, type = "fixed")
+          subtitles(fixed_effects_table) <- st
         },
         env = list(
           fit_mmrm = as.name(fit_name),
@@ -311,7 +309,6 @@ template_mmrm_tables <- function(parentname,
         expr = {
           diagnostic_table <- tern.mmrm::as.rtable(fit_mmrm, type = "diagnostic")
           subtitles(diagnostic_table) <- st
-          diagnostic_table
         },
         env = list(
           fit_mmrm = as.name(fit_name),
@@ -443,6 +440,7 @@ template_mmrm_plots <- function(fit_name,
 #' This module produces analysis tables and plots for Mixed Model Repeated Measurements.
 #'
 #' @inheritParams module_arguments
+#' @inheritParams teal::module
 #' @inheritParams template_mmrm_tables
 #' @inheritParams template_mmrm_plots
 #' @param method ([teal.transform::choices_selected()])\cr object with
@@ -461,8 +459,48 @@ template_mmrm_plots <- function(fit_name,
 #'
 #' @inherit module_arguments return seealso
 #'
+#' @section Decorating Module:
+#'
+#' This module generates the following objects, which can be modified in place using decorators:
+#' - `lsmeans_plot` (`ggplot`)
+#' - `diagnostic_plot` (`ggplot`)
+#' - `lsmeans_table` (`TableTree`- output from `rtables::build_table`)
+#' - `covariance_table` (`ElementaryTable`- output from `rtables::build_table`)
+#' - `fixed_effects_table` (`ElementaryTable`- output from `rtables::build_table`)
+#' - `diagnostic_table` (`ElementaryTable`- output from `rtables::build_table`)
+#'
+#' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
+#' The name of this list corresponds to the name of the output to which the decorator is applied.
+#' See code snippet below:
+#'
+#' ```
+#' tm_a_mrmm(
+#'    ..., # arguments for module
+#'    decorators = list(
+#'      lsmeans_plot = teal_transform_module(...), # applied only to `lsmeans_plot` output
+#'      diagnostic_plot = teal_transform_module(...), # applied only to `diagnostic_plot` output
+#'      lsmeans_table = teal_transform_module(...), # applied only to `lsmeans_table` output
+#'      covariance_table = teal_transform_module(...), # applied only to `covariance_table` output
+#'      fixed_effects_table = teal_transform_module(...), # applied only to `fixed_effects_table` output
+#'      diagnostic_table = teal_transform_module(...) # applied only to `diagnostic_table` output
+#'    )
+#' )
+#' ```
+#'
+#' For additional details and examples of decorators, refer to the vignette
+#' `vignette("decorate-module-output", package = "teal.modules.clinical")`.
+#'
+#' To learn more please refer to the vignette
+#' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
+#'
+#' @examplesShinylive
+#' library(teal.modules.clinical)
+#' interactive <- function() TRUE
+#' {{ next_example }}
+#'
 #' @examples
 #' library(dplyr)
+#'
 #' arm_ref_comp <- list(
 #'   ARMCD = list(
 #'     ref = "ARM B",
@@ -484,10 +522,8 @@ template_mmrm_plots <- function(fit_name,
 #'         as.factor() #' making consecutive numeric factor
 #'     )
 #' })
+#' join_keys(data) <- default_cdisc_join_keys[names(data)]
 #'
-#' datanames <- c("ADSL", "ADQS")
-#' datanames(data) <- datanames
-#' join_keys(data) <- default_cdisc_join_keys[datanames]
 #' app <- init(
 #'   data = data,
 #'   modules = modules(
@@ -538,7 +574,9 @@ tm_a_mmrm <- function(label,
                       pre_output = NULL,
                       post_output = NULL,
                       basic_table_args = teal.widgets::basic_table_args(),
-                      ggplot2_args = teal.widgets::ggplot2_args()) {
+                      ggplot2_args = teal.widgets::ggplot2_args(),
+                      transformators = list(),
+                      decorators = list()) {
   message("Initializing tm_a_mmrm")
   cov_var <- teal.transform::add_no_selected_choices(cov_var, multiple = TRUE)
   checkmate::assert_string(label)
@@ -567,6 +605,18 @@ tm_a_mmrm <- function(label,
   checkmate::assert_list(ggplot2_args, types = "ggplot2_args")
   checkmate::assert_subset(names(ggplot2_args), c("default", plot_choices))
 
+  assert_decorators(
+    decorators,
+    c(
+      "lsmeans_table",
+      "lsmeans_plot",
+      "covariance_table",
+      "fixed_effects_table",
+      "diagnostic_table",
+      "diagnostic_plot"
+    )
+  )
+
   args <- as.list(environment())
 
   data_extract_list <- list(
@@ -595,9 +645,11 @@ tm_a_mmrm <- function(label,
         plot_height = plot_height,
         plot_width = plot_width,
         basic_table_args = basic_table_args,
-        ggplot2_args = ggplot2_args
+        ggplot2_args = ggplot2_args,
+        decorators = decorators
       )
     ),
+    transformators = transformators,
     datanames = teal.transform::get_extract_datanames(data_extract_list)
   )
 }
@@ -749,6 +801,32 @@ ui_mmrm <- function(id, ...) {
           ),
           selected = "t_mmrm_lsmeans"
         ),
+        # Decorators ---
+        conditionalPanel(
+          condition = sprintf("input['%s'] == '%s'", ns("output_function"), "t_mmrm_lsmeans"),
+          ui_decorate_teal_data(ns("d_lsmeans_table"), select_decorators(a$decorators, "lsmeans_table"))
+        ),
+        conditionalPanel(
+          condition = sprintf("input['%s'] == '%s'", ns("output_function"), "g_mmrm_lsmeans"),
+          ui_decorate_teal_data(ns("d_lsmeans_plot"), select_decorators(a$decorators, "lsmeans_plot"))
+        ),
+        conditionalPanel(
+          condition = sprintf("input['%s'] == '%s'", ns("output_function"), "t_mmrm_cov"),
+          ui_decorate_teal_data(ns("d_covariance_table"), select_decorators(a$decorators, "covariance_table"))
+        ),
+        conditionalPanel(
+          condition = sprintf("input['%s'] == '%s'", ns("output_function"), "t_mmrm_fixed"),
+          ui_decorate_teal_data(ns("d_fixed_effects_table"), select_decorators(a$decorators, "fixed_effects_table"))
+        ),
+        conditionalPanel(
+          condition = sprintf("input['%s'] == '%s'", ns("output_function"), "t_mmrm_diagnostic"),
+          ui_decorate_teal_data(ns("d_diagnostic_table"), select_decorators(a$decorators, "diagnostic_table"))
+        ),
+        conditionalPanel(
+          condition = sprintf("input['%s'] == '%s'", ns("output_function"), "g_mmrm_diagnostic"),
+          ui_decorate_teal_data(ns("d_diagnostic_plot"), select_decorators(a$decorators, "diagnostic_plot"))
+        ),
+        # End of Decorators ---
         conditionalPanel(
           condition = paste0(
             "input['", ns("output_function"), "'] == 't_mmrm_lsmeans'", " || ",
@@ -811,7 +889,6 @@ ui_mmrm <- function(id, ...) {
       )
     ),
     forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("warning"), "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), "Show R code")
     ),
     pre_output = a$pre_output,
@@ -839,13 +916,15 @@ srv_mmrm <- function(id,
                      plot_height,
                      plot_width,
                      basic_table_args,
-                     ggplot2_args) {
+                     ggplot2_args,
+                     decorators) {
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(isolate(data()), "teal_data")
 
   moduleServer(id, function(input, output, session) {
+    teal.logger::log_shiny_input_changes(input, namespace = "teal.modules.clinical")
     # Reactive responsible for sending a disable/enable signal
     # to show R code and debug info buttons
     disable_r_code <- reactiveVal(FALSE)
@@ -1239,7 +1318,7 @@ srv_mmrm <- function(id,
         weights_emmeans = input$weights_emmeans,
         parallel = input$parallel
       )
-      teal.code::eval_code(qenv, as.expression(my_calls))
+      teal.code::eval_code(qenv, as.expression(unlist(my_calls)))
     })
 
     output$mmrm_title <- renderText({
@@ -1394,30 +1473,62 @@ srv_mmrm <- function(id,
       teal.code::eval_code(qenv, as.expression(mmrm_plot_expr))
     })
 
-    all_q <- reactive({
-      if (!is.null(plot_q()) && !is.null(table_q())) {
-        teal.code::join(plot_q(), table_q())
-      } else if (!is.null(plot_q())) {
-        plot_q()
-      } else {
-        table_q()
+    decorated_tables_q <- lapply(
+      stats::setNames(
+        nm = c("lsmeans_table", "diagnostic_table", "fixed_effects_table", "covariance_table")
+      ),
+      function(output_function) {
+        srv_decorate_teal_data(
+          id = sprintf("d_%s", output_function),
+          data = table_q,
+          decorators = select_decorators(decorators, output_function),
+          expr = reactive(bquote(.(as.name(output_function)))),
+          expr_is_reactive = TRUE
+        )
       }
-    })
+    )
 
-    table_r <- reactive({
+    decorated_objs_q <- c(
+      decorated_tables_q,
+      lapply(
+        stats::setNames(nm = c("lsmeans_plot", "diagnostic_plot")),
+        function(output_function) {
+          srv_decorate_teal_data(
+            id = sprintf("d_%s", output_function),
+            data = plot_q,
+            decorators = select_decorators(decorators, output_function),
+            expr = reactive(bquote(.(as.name(output_function)))),
+            expr_is_reactive = TRUE
+          )
+        }
+      )
+    )
+
+    obj_ix_r <- reactive({
       switch(input$output_function,
-        t_mmrm_lsmeans = table_q()[["lsmeans_table"]],
-        t_mmrm_diagnostic = table_q()[["diagnostic_table"]],
-        t_mmrm_fixed = table_q()[["fixed_effects"]],
-        t_mmrm_cov = table_q()[["cov_matrix"]]
+        t_mmrm_lsmeans = "lsmeans_table",
+        t_mmrm_diagnostic = "diagnostic_table",
+        t_mmrm_fixed = "fixed_effects_table",
+        t_mmrm_cov = "covariance_table",
+        g_mmrm_lsmeans = "lsmeans_plot",
+        g_mmrm_diagnostic = "diagnostic_plot"
       )
     })
 
     plot_r <- reactive({
-      switch(input$output_function,
-        g_mmrm_lsmeans = plot_q()[["lsmeans_plot"]],
-        g_mmrm_diagnostic = plot_q()[["diagnostic_plot"]]
-      )
+      if (is.null(plot_q())) {
+        NULL
+      } else {
+        decorated_objs_q[[obj_ix_r()]]()[[obj_ix_r()]]
+      }
+    })
+
+    table_r <- reactive({
+      if (is.null(table_q())) {
+        NULL
+      } else {
+        decorated_objs_q[[obj_ix_r()]]()[[obj_ix_r()]]
+      }
     })
 
     pws <- teal.widgets::plot_with_settings_srv(
@@ -1434,17 +1545,13 @@ srv_mmrm <- function(id,
       show_hide_signal = reactive(!show_plot_rv())
     )
 
-    teal.widgets::verbatim_popup_srv(
-      id = "warning",
-      verbatim_content = reactive(teal.code::get_warnings(all_q())),
-      title = "Warning",
-      disabled = reactive(disable_r_code() || is.null(teal.code::get_warnings(all_q())))
-    )
-
     # Show R code once button is pressed.
+    source_code_r <- reactive(
+      teal.code::get_code(req(decorated_objs_q[[obj_ix_r()]]()))
+    )
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = reactive(teal.code::get_code(all_q())),
+      verbatim_content = source_code_r,
       disabled = disable_r_code,
       title = "R Code for the Current MMRM Analysis"
     )
@@ -1474,7 +1581,7 @@ srv_mmrm <- function(id,
           card$append_text("Comment", "header3")
           card$append_text(comment)
         }
-        card$append_src(teal.code::get_code(all_q()))
+        card$append_src(source_code_r())
         card
       }
       teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
