@@ -6,6 +6,7 @@
 #' `x_facet`, and `y_facet` parameters. Any parameters set to `NULL` (default) are ignored.
 #'
 #' @inheritParams module_arguments
+#' @inheritParams teal::module
 #' @inheritParams template_arguments
 #' @param x (`data_extract_spec`)\cr variable on the x-axis.
 #' @param fill (`data_extract_spec`)\cr grouping variable to determine bar colors.
@@ -15,26 +16,54 @@
 #'
 #' @inherit module_arguments return seealso
 #'
+#' @section Decorating Module:
+#'
+#' This module generates the following objects, which can be modified in place using decorators:
+#' - `plot` (`ggplot`)
+#'
+#' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
+#' The name of this list corresponds to the name of the output to which the decorator is applied.
+#' See code snippet below:
+#'
+#' ```
+#' tm_g_barchart_simple(
+#'    ..., # arguments for module
+#'    decorators = list(
+#'      plot = teal_transform_module(...) # applied only to `plot` output
+#'    )
+#' )
+#' ```
+#'
+#' For additional details and examples of decorators, refer to the vignette
+#' `vignette("decorate-module-output", package = "teal.modules.clinical")`.
+#'
+#' To learn more please refer to the vignette
+#' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
+#'
+#' @examplesShinylive
+#' library(teal.modules.clinical)
+#' interactive <- function() TRUE
+#' {{ next_example }}
+#'
 #' @examples
 #' library(nestcolor)
 #' library(dplyr)
 #'
-#' ADSL <- tmc_ex_adsl %>%
-#'   mutate(ITTFL = factor("Y") %>%
-#'     with_label("Intent-To-Treat Population Flag"))
-#' ADAE <- tmc_ex_adae %>%
-#'   filter(!((AETOXGR == 1) & (AESEV == "MILD") & (ARM == "A: Drug X")))
+#' data <- teal_data()
+#' data <- within(data, {
+#'   ADSL <- tmc_ex_adsl %>%
+#'     mutate(ITTFL = factor("Y") %>%
+#'       with_label("Intent-To-Treat Population Flag"))
+#'   ADAE <- tmc_ex_adae %>%
+#'     filter(!((AETOXGR == 1) & (AESEV == "MILD") & (ARM == "A: Drug X")))
+#' })
+#' join_keys(data) <- default_cdisc_join_keys[names(data)]
+#'
+#' ADSL <- data[["ADSL"]]
+#' ADAE <- data[["ADAE"]]
 #'
 #' app <- init(
-#'   data = cdisc_data(
-#'     ADSL = ADSL,
-#'     ADAE = ADAE,
-#'     code = "ADSL <- tmc_ex_adsl %>%
-#'               mutate(ITTFL = factor(\"Y\") %>%
-#'               with_label(\"Intent-To-Treat Population Flag\"))
-#'             ADAE <- tmc_ex_adae %>%
-#'               filter(!((AETOXGR == 1) & (AESEV == \"MILD\") & (ARM == \"A: Drug X\")))"
-#'   ),
+#'   data = data,
 #'   modules = modules(
 #'     tm_g_barchart_simple(
 #'       label = "ADAE Analysis",
@@ -142,7 +171,9 @@ tm_g_barchart_simple <- function(x = NULL,
                                  plot_width = NULL,
                                  pre_output = NULL,
                                  post_output = NULL,
-                                 ggplot2_args = teal.widgets::ggplot2_args()) {
+                                 ggplot2_args = teal.widgets::ggplot2_args(),
+                                 transformators = list(),
+                                 decorators = list()) {
   message("Initializing tm_g_barchart_simple")
   checkmate::assert_string(label)
   checkmate::assert_list(plot_options, null.ok = TRUE)
@@ -167,6 +198,7 @@ tm_g_barchart_simple <- function(x = NULL,
   checkmate::assert_class(pre_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(post_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(ggplot2_args, "ggplot2_args")
+  assert_decorators(decorators, names = "plot")
 
   plot_options <- utils::modifyList(
     list(stacked = FALSE), # default
@@ -174,6 +206,12 @@ tm_g_barchart_simple <- function(x = NULL,
   )
 
   ui_args <- as.list(environment())
+
+  data_extract_list <- list(
+    x = x, fill = fill,
+    x_facet = x_facet, y_facet = y_facet
+  )
+
   module(
     label = label,
     server = srv_g_barchart_simple,
@@ -186,9 +224,11 @@ tm_g_barchart_simple <- function(x = NULL,
       y_facet = y_facet,
       plot_height = plot_height,
       plot_width = plot_width,
-      ggplot2_args = ggplot2_args
+      ggplot2_args = ggplot2_args,
+      decorators = decorators
     ),
-    datanames = "all"
+    transformators = transformators,
+    datanames = teal.transform::get_extract_datanames(data_extract_list)
   )
 }
 
@@ -245,6 +285,7 @@ ui_g_barchart_simple <- function(id, ...) {
             is_single_dataset = is_single_dataset_value
           )
         },
+        ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(args$decorators, "plot")),
         teal.widgets::panel_group(
           teal.widgets::panel_item(
             "Additional plot settings",
@@ -314,7 +355,6 @@ ui_g_barchart_simple <- function(id, ...) {
       )
     ),
     forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
     pre_output = args$pre_output,
@@ -333,13 +373,15 @@ srv_g_barchart_simple <- function(id,
                                   y_facet,
                                   plot_height,
                                   plot_width,
-                                  ggplot2_args) {
+                                  ggplot2_args,
+                                  decorators) {
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(isolate(data()), "teal_data")
 
   moduleServer(id, function(input, output, session) {
+    teal.logger::log_shiny_input_changes(input, namespace = "teal.modules.clinical")
     rule_dupl <- function(others) {
       function(value) {
         othervals <- lapply(
@@ -416,7 +458,9 @@ srv_g_barchart_simple <- function(id,
         count_exprs <- c(count_exprs, count_exprs2, count_str_to_col_exprs)
       }
 
-      data_list <- sapply(teal.data::datanames(data()), function(x) reactive(data()[[x]]),
+      data_list <- sapply(
+        names(data()),
+        function(x) reactive(data()[[x]]),
         simplify = FALSE
       )
 
@@ -500,13 +544,16 @@ srv_g_barchart_simple <- function(id,
           )
         )) %>%
         teal.code::eval_code(code = plot_call)
-
-      # explicitly calling print on the plot inside the qenv evaluates
-      # the ggplot call and therefore catches errors
-      teal.code::eval_code(all_q, code = quote(print(plot)))
     })
 
-    plot_r <- reactive(all_q()[["plot"]])
+    decorated_all_q_code <- srv_decorate_teal_data(
+      "decorator",
+      data = all_q,
+      decorators = select_decorators(decorators, "plot"),
+      expr = print(plot)
+    )
+
+    plot_r <- reactive(decorated_all_q_code()[["plot"]])
 
     output$table <- renderTable({
       req(iv_r()$is_valid())
@@ -542,16 +589,11 @@ srv_g_barchart_simple <- function(id,
       width = plot_width
     )
 
-    teal.widgets::verbatim_popup_srv(
-      id = "warning",
-      verbatim_content = reactive(teal.code::get_warnings(all_q())),
-      title = "Warning",
-      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
-    )
-
+    # Render R code
+    source_code_r <- reactive(teal.code::get_code(req(decorated_all_q_code())))
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = reactive(teal.code::get_code(all_q())),
+      verbatim_content = source_code_r,
       title = "Bar Chart"
     )
 
@@ -570,7 +612,7 @@ srv_g_barchart_simple <- function(id,
           card$append_text("Comment", "header3")
           card$append_text(comment)
         }
-        card$append_src(teal.code::get_code(all_q()))
+        card$append_src(source_code_r())
         card
       }
       teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
