@@ -5,6 +5,8 @@
 #' @inheritParams tern::g_lineplot
 #' @inheritParams tern::control_lineplot_vars
 #' @inheritParams template_arguments
+#' @param strata `r lifecycle::badge("deprecated")` Please use the `group_var` argument instead.
+#' @param group_var (`string` or `NA`)\cr group variable name.
 #' @param param (`character`)\cr parameter to filter the data by.
 #' @param incl_screen (`logical`)\cr whether the screening visit should be included.
 #' @param ggplot2_args (`ggplot2_args`) optional\cr object created by [teal.widgets::ggplot2_args()] with settings
@@ -21,7 +23,8 @@
 #'
 #' @keywords internal
 template_g_lineplot <- function(dataname = "ANL",
-                                strata = "ARM",
+                                strata = lifecycle::deprecated(),
+                                group_var = "ARM",
                                 x = "AVISIT",
                                 y = "AVAL",
                                 y_unit = "AVALU",
@@ -39,8 +42,17 @@ template_g_lineplot <- function(dataname = "ANL",
                                 title = "Line Plot",
                                 y_lab = "",
                                 ggplot2_args = teal.widgets::ggplot2_args()) {
+  if (lifecycle::is_present(strata)) {
+    warning(
+      "The `strata` argument of `template_g_lineplot()` is deprecated as of teal.modules.clinical 0.9.1. ",
+      "Please use the `group_var` argument instead.",
+      call. = FALSE
+    )
+    group_var <- strata
+  }
+
   checkmate::assert_string(dataname)
-  checkmate::assert_string(strata)
+  checkmate::assert_string(group_var)
   checkmate::assert_string(x)
   checkmate::assert_string(y)
   checkmate::assert_string(y_unit)
@@ -71,7 +83,7 @@ template_g_lineplot <- function(dataname = "ANL",
     )
   }
 
-  # droplevels for strata
+  # droplevels for group_var
   data_list <- add_expr(
     data_list,
     substitute_names(
@@ -79,7 +91,7 @@ template_g_lineplot <- function(dataname = "ANL",
         arm_var = droplevels(arm_var)
       ),
       names = list(
-        arm_var = as.name(strata)
+        arm_var = as.name(group_var)
       )
     )
   )
@@ -94,8 +106,8 @@ template_g_lineplot <- function(dataname = "ANL",
   )
 
   z$variables <- substitute(
-    expr = variables <- control_lineplot_vars(x = x, y = y, strata = arm, paramcd = paramcd, y_unit = y_unit),
-    env = list(x = x, y = y, arm = strata, paramcd = paramcd, y_unit = y_unit)
+    expr = variables <- control_lineplot_vars(x = x, y = y, group_var = arm, paramcd = paramcd, y_unit = y_unit),
+    env = list(x = x, y = y, arm = group_var, paramcd = paramcd, y_unit = y_unit)
   )
 
   mid_choices <- c(
@@ -183,10 +195,7 @@ template_g_lineplot <- function(dataname = "ANL",
   graph_list <- add_expr(
     graph_list,
     substitute(
-      expr = {
-        plot <- plot_call
-        plot
-      },
+      expr = plot <- plot_call,
       env = list(plot_call = plot_call)
     )
   )
@@ -201,32 +210,63 @@ template_g_lineplot <- function(dataname = "ANL",
 #' This module produces a [ggplot2::ggplot()] type line plot, with optional summary table, for standard ADaM data.
 #'
 #' @inheritParams module_arguments
+#' @inheritParams teal::module
 #' @inheritParams template_g_lineplot
 #'
 #' @inherit module_arguments return seealso
 #'
+#' @section Decorating Module:
+#'
+#' This module generates the following objects, which can be modified in place using decorators:
+#' - `plot` (`ggplot`)
+#'
+#' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
+#' The name of this list corresponds to the name of the output to which the decorator is applied.
+#' See code snippet below:
+#'
+#' ```
+#' tm_g_lineplot(
+#'    ..., # arguments for module
+#'    decorators = list(
+#'      plot = teal_transform_module(...) # applied only to `plot` output
+#'    )
+#' )
+#' ```
+#'
+#' For additional details and examples of decorators, refer to the vignette
+#' `vignette("decorate-module-output", package = "teal.modules.clinical")`.
+#'
+#' To learn more please refer to the vignette
+#' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
+#'
+#' @examplesShinylive
+#' library(teal.modules.clinical)
+#' interactive <- function() TRUE
+#' {{ next_example }}
+#'
 #' @examples
 #' library(nestcolor)
 #' library(dplyr)
 #' library(forcats)
 #'
-#' ADSL <- tmc_ex_adsl
-#' ADLB <- tmc_ex_adlb %>% mutate(AVISIT == fct_reorder(AVISIT, AVISITN, min))
+#' data <- teal_data()
+#' data <- within(data, {
+#'   ADSL <- tmc_ex_adsl
+#'   ADLB <- tmc_ex_adlb %>%
+#'     mutate(AVISIT == fct_reorder(AVISIT, AVISITN, min))
+#' })
+#' join_keys(data) <- default_cdisc_join_keys[names(data)]
+#'
+#' ADSL <- data[["ADSL"]]
+#' ADLB <- data[["ADLB"]]
 #'
 #' app <- init(
-#'   data = cdisc_data(
-#'     ADSL = ADSL,
-#'     ADLB = ADLB,
-#'     code = "
-#'       ADSL <- tmc_ex_adsl
-#'       ADLB <- tmc_ex_adlb %>% mutate(AVISIT == fct_reorder(AVISIT, AVISITN, min))
-#'     "
-#'   ),
+#'   data = data,
 #'   modules = modules(
 #'     tm_g_lineplot(
 #'       label = "Line Plot",
 #'       dataname = "ADLB",
-#'       strata = choices_selected(
+#'       group_var = choices_selected(
 #'         variable_choices(ADSL, c("ARM", "ARMCD", "ACTARMCD")),
 #'         "ARM"
 #'       ),
@@ -248,12 +288,9 @@ template_g_lineplot <- function(dataname = "ANL",
 #' @export
 tm_g_lineplot <- function(label,
                           dataname,
-                          parentname = ifelse(
-                            inherits(strata, "data_extract_spec"),
-                            teal.transform::datanames_input(strata),
-                            "ADSL"
-                          ),
-                          strata = teal.transform::choices_selected(
+                          parentname = NULL,
+                          strata = lifecycle::deprecated(),
+                          group_var = teal.transform::choices_selected(
                             teal.transform::variable_choices(parentname, c("ARM", "ARMCD", "ACTARMCD")), "ARM"
                           ),
                           x = teal.transform::choices_selected(
@@ -286,7 +323,28 @@ tm_g_lineplot <- function(label,
                           plot_width = NULL,
                           pre_output = NULL,
                           post_output = NULL,
-                          ggplot2_args = teal.widgets::ggplot2_args()) {
+                          ggplot2_args = teal.widgets::ggplot2_args(),
+                          transformators = list(),
+                          decorators = list()) {
+  if (lifecycle::is_present(strata)) {
+    warning(
+      "The `strata` argument of `tm_g_lineplot()` is deprecated as of teal.modules.clinical 0.9.1. ",
+      "Please use the `group_var` argument instead.",
+      call. = FALSE
+    )
+    group_var <- strata
+  } else {
+    strata <- group_var # resolves missing argument error
+  }
+
+  # Now handle 'parentname' calculation based on 'group_var'
+  if (is.null(parentname)) {
+    parentname <- ifelse(
+      inherits(group_var, "data_extract_spec"),
+      teal.transform::datanames_input(group_var),
+      "ADSL"
+    )
+  }
   message("Initializing tm_g_lineplot")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
@@ -307,9 +365,11 @@ tm_g_lineplot <- function(label,
   checkmate::assert_class(post_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(ggplot2_args, "ggplot2_args")
 
+  assert_decorators(decorators, "plot")
+
   args <- as.list(environment())
   data_extract_list <- list(
-    strata = cs_to_des_select(strata, dataname = parentname),
+    group_var = cs_to_des_select(group_var, dataname = parentname),
     param = cs_to_des_filter(param, dataname = dataname),
     x = cs_to_des_select(x, dataname = dataname, multiple = FALSE),
     y = cs_to_des_select(y, dataname = dataname, multiple = FALSE),
@@ -330,9 +390,11 @@ tm_g_lineplot <- function(label,
         parentname = parentname,
         plot_height = plot_height,
         plot_width = plot_width,
-        ggplot2_args = ggplot2_args
+        ggplot2_args = ggplot2_args,
+        decorators = decorators
       )
     ),
+    transformators = transformators,
     datanames = teal.transform::get_extract_datanames(data_extract_list)
   )
 }
@@ -341,7 +403,7 @@ tm_g_lineplot <- function(label,
 ui_g_lineplot <- function(id, ...) {
   a <- list(...)
   is_single_dataset_value <- teal.transform::is_single_dataset(
-    a$strata,
+    a$group_var,
     a$paramcd,
     a$x,
     a$param,
@@ -362,7 +424,7 @@ ui_g_lineplot <- function(id, ...) {
       teal.reporter::simple_reporter_ui(ns("simple_reporter")),
       ###
       tags$label("Encodings", class = "text-primary"),
-      teal.transform::datanames_input(a[c("strata", "paramcd", "x", "y", "y_unit", "param")]),
+      teal.transform::datanames_input(a[c("group_var", "paramcd", "x", "y", "y_unit", "param")]),
       teal.transform::data_extract_ui(
         id = ns("param"),
         label = "Select Biomarker",
@@ -370,9 +432,9 @@ ui_g_lineplot <- function(id, ...) {
         is_single_dataset = is_single_dataset_value
       ),
       teal.transform::data_extract_ui(
-        id = ns("strata"),
+        id = ns("group_var"),
         label = "Select Treatment Variable",
-        data_extract_spec = a$strata,
+        data_extract_spec = a$group_var,
         is_single_dataset = is_single_dataset_value
       ),
       teal.transform::data_extract_ui(
@@ -412,6 +474,7 @@ ui_g_lineplot <- function(id, ...) {
         "Include screening visit",
         value = TRUE
       ),
+      ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "plot")),
       teal.widgets::panel_group(
         teal.widgets::panel_item(
           "Additional plot settings",
@@ -486,7 +549,6 @@ ui_g_lineplot <- function(id, ...) {
       )
     ),
     forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
     pre_output = a$pre_output,
@@ -502,7 +564,7 @@ srv_g_lineplot <- function(id,
                            dataname,
                            parentname,
                            paramcd,
-                           strata,
+                           group_var,
                            x,
                            y,
                            param,
@@ -510,20 +572,22 @@ srv_g_lineplot <- function(id,
                            label,
                            plot_height,
                            plot_width,
-                           ggplot2_args) {
+                           ggplot2_args,
+                           decorators) {
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(isolate(data()), "teal_data")
 
   moduleServer(id, function(input, output, session) {
+    teal.logger::log_shiny_input_changes(input, namespace = "teal.modules.clinical")
     selector_list <- teal.transform::data_extract_multiple_srv(
-      data_extract = list(x = x, y = y, strata = strata, paramcd = paramcd, y_unit = y_unit, param = param),
+      data_extract = list(x = x, y = y, group_var = group_var, paramcd = paramcd, y_unit = y_unit, param = param),
       datasets = data,
       select_validation_rule = list(
         x = shinyvalidate::sv_required("Please select a time variable"),
         y = shinyvalidate::sv_required("Please select an analysis variable"),
-        strata = shinyvalidate::sv_required("Please select a treatment variable")
+        group_var = shinyvalidate::sv_required("Please select a treatment variable")
       ),
       filter_validation_rule = list(
         param = shinyvalidate::sv_required(message = "Please select Biomarker filter.")
@@ -562,7 +626,7 @@ srv_g_lineplot <- function(id,
       adsl_filtered <- merged$anl_q()[[parentname]]
       anl_filtered <- merged$anl_q()[[dataname]]
 
-      input_strata <- names(merged$anl_input_r()$columns_source$strata)
+      input_strata <- names(merged$anl_input_r()$columns_source$group_var)
       input_x_var <- names(merged$anl_input_r()$columns_source$x)
       input_y <- names(merged$anl_input_r()$columns_source$y)
       input_param <- unlist(param$filter)["vars_selected"]
@@ -605,7 +669,7 @@ srv_g_lineplot <- function(id,
 
       my_calls <- template_g_lineplot(
         dataname = "ANL",
-        strata = names(merged$anl_input_r()$columns_source$strata),
+        group_var = names(merged$anl_input_r()$columns_source$group_var),
         y = names(merged$anl_input_r()$columns_source$y),
         x = names(merged$anl_input_r()$columns_source$x),
         paramcd = names(merged$anl_input_r()$columns_source$paramcd),
@@ -621,10 +685,16 @@ srv_g_lineplot <- function(id,
         table_font_size = input$table_font_size,
         ggplot2_args = ggplot2_args
       )
-      teal.code::eval_code(merged$anl_q(), as.expression(my_calls))
+      teal.code::eval_code(merged$anl_q(), as.expression(unlist(my_calls)))
     })
 
-    plot_r <- reactive(all_q()[["plot"]])
+    decorated_all_q <- srv_decorate_teal_data(
+      id = "decorator",
+      data = all_q,
+      decorators = select_decorators(decorators, "plot"),
+      expr = print(plot)
+    )
+    plot_r <- reactive(decorated_all_q()[["plot"]])
 
     # Insert the plot into a plot with settings module from teal.widgets
     pws <- teal.widgets::plot_with_settings_srv(
@@ -634,16 +704,11 @@ srv_g_lineplot <- function(id,
       width = plot_width
     )
 
-    teal.widgets::verbatim_popup_srv(
-      id = "warning",
-      verbatim_content = reactive(teal.code::get_warnings(all_q())),
-      title = "Warning",
-      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
-    )
-
+    # Render R code
+    source_code_r <- reactive(teal.code::get_code(req(decorated_all_q())))
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = reactive(teal.code::get_code(all_q())),
+      verbatim_content = source_code_r,
       title = label
     )
 
@@ -662,7 +727,7 @@ srv_g_lineplot <- function(id,
           card$append_text("Comment", "header3")
           card$append_text(comment)
         }
-        card$append_src(teal.code::get_code(all_q()))
+        card$append_src(source_code_r())
         card
       }
       teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
