@@ -65,34 +65,27 @@ template_therapy <- function(dataname = "ANL",
 
       dataname[setdiff(cols_to_include, names(dataname))] <- NA
 
-      therapy_table <-
-        dataname %>%
+      table <- dataname %>%
         dplyr::filter(atirel %in% c("CONCOMITANT", "PRIOR")) %>% # removed PRIOR_CONCOMITANT
         dplyr::select(dplyr::all_of(cols_to_include)) %>%
         dplyr::filter(!is.na(cmdecod)) %>%
         dplyr::mutate(Dosage = paste(cmdose, cmdosu, cmdosfrq, cmroute)) %>%
         dplyr::select(-cmdose, -cmdosu, -cmdosfrq, -cmroute) %>%
         dplyr::select(cmindc, cmdecod, Dosage, dplyr::everything()) %>%
-        dplyr::mutate(CMDECOD = dplyr::case_when(
+        dplyr::mutate(!!cmdecod_char := dplyr::case_when(
           nchar(as.character(cmdecod)) > 20 ~ as.character(cmtrt),
           TRUE ~ as.character(cmdecod)
         )) %>%
         dplyr::select(-cmtrt) %>%
         dplyr::arrange(cmindc, cmdecod, cmstdy) %>%
         dplyr::distinct() %>%
+        dplyr::mutate(!!cmstdy_char := as.character(cmstdy_char), !!cmendy_char := as.character(cmendy_char)) %>%
         `colnames<-`(c(
           col_labels(dataname, fill = TRUE)[c(cmindc_char, cmdecod_char)], "Dosage",
           col_labels(dataname, fill = TRUE)[c(cmstdy_char, cmendy_char)]
         ))
 
-      therapy_table <- rlistings::as_listing(
-        therapy_table,
-        key_cols = NULL,
-        default_formatting = list(all = fmt_config(align = "left"))
-      )
-      main_title(therapy_table) <- paste("Patient ID:", patient_id)
-
-      therapy_table
+      table <- DT::datatable(table)
     }, env = list(
       dataname = as.name(dataname),
       atirel = as.name(atirel),
@@ -174,7 +167,7 @@ template_therapy <- function(dataname = "ANL",
           TRUE ~ as.character(cmdecod)
         ))
 
-      therapy_plot <-
+      plot <-
         ggplot2::ggplot(data = data, ggplot2::aes(fill = cmindc, color = cmindc, y = CMDECOD, x = CMSTDY)) +
         ggplot2::geom_segment(ggplot2::aes(xend = CMENDY, yend = CMDECOD), size = 2) +
         ggplot2::geom_text(
@@ -192,8 +185,6 @@ template_therapy <- function(dataname = "ANL",
         labs +
         ggtheme +
         theme
-
-      print(therapy_plot)
     }, env = c(
       list(
         dataname = as.name(dataname),
@@ -232,6 +223,7 @@ template_therapy <- function(dataname = "ANL",
 #' This module produces a patient profile therapy table and [ggplot2::ggplot()] type plot using ADaM datasets.
 #'
 #' @inheritParams module_arguments
+#' @inheritParams teal::module
 #' @inheritParams template_therapy
 #' @param cmdose ([teal.transform::choices_selected()])\cr object with all
 #'   available choices and preselected option for the `CMDOSE` variable from `dataname`.
@@ -248,31 +240,58 @@ template_therapy <- function(dataname = "ANL",
 #'
 #' @inherit module_arguments return
 #'
+#' @section Decorating Module:
+#'
+#' This module generates the following objects, which can be modified in place using decorators::
+#' - `plot` (`ggplot`)
+#' - `table` (`datatables` - output of `DT::datatable()`)
+#'
+#' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
+#' The name of this list corresponds to the name of the output to which the decorator is applied.
+#' See code snippet below:
+#'
+#' ```
+#' tm_g_pp_therapy(
+#'    ..., # arguments for module
+#'    decorators = list(
+#'      plot = teal_transform_module(...), # applied only to `plot` output
+#'      table = teal_transform_module(...) # applied only to `table` output
+#'    )
+#' )
+#' ```
+#'
+#' For additional details and examples of decorators, refer to the vignette
+#' `vignette("decorate-module-output", package = "teal.modules.clinical")`.
+#'
+#' To learn more please refer to the vignette
+#' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
+#'
+#' @examplesShinylive
+#' library(teal.modules.clinical)
+#' interactive <- function() TRUE
+#' {{ next_example }}
+#'
 #' @examples
 #' library(nestcolor)
 #' library(dplyr)
 #'
-#' ADCM <- tmc_ex_adcm
-#' ADSL <- tmc_ex_adsl %>% filter(USUBJID %in% ADCM$USUBJID)
-#' ADCM$CMASTDTM <- ADCM$ASTDTM
-#' ADCM$CMAENDTM <- ADCM$AENDTM
-#' adcm_keys <- c("STUDYID", "USUBJID", "ASTDTM", "CMSEQ", "ATC1", "ATC2", "ATC3", "ATC4")
+#' data <- teal_data()
+#' data <- within(data, {
+#'   ADCM <- tmc_ex_adcm
+#'   ADSL <- tmc_ex_adsl %>% filter(USUBJID %in% ADCM$USUBJID)
+#'   ADCM$CMASTDTM <- ADCM$ASTDTM
+#'   ADCM$CMAENDTM <- ADCM$AENDTM
+#' })
 #'
-#' join_keys <- default_cdisc_join_keys[c("ADSL", "ADCM")]
-#' join_keys["ADCM", "ADCM"] <- adcm_keys
+#' join_keys(data) <- default_cdisc_join_keys[c("ADSL", "ADCM")]
+#' adcm_keys <- c("STUDYID", "USUBJID", "ASTDTM", "CMSEQ", "ATC1", "ATC2", "ATC3", "ATC4")
+#' join_keys(data)["ADCM", "ADCM"] <- adcm_keys
+#'
+#' ADSL <- data[["ADSL"]]
+#' ADCM <- data[["ADCM"]]
 #'
 #' app <- init(
-#'   data = cdisc_data(
-#'     ADSL = ADSL,
-#'     ADCM = ADCM,
-#'     code = "
-#'       ADCM <- tmc_ex_adcm
-#'       ADSL <- tmc_ex_adsl %>% filter(USUBJID %in% ADCM$USUBJID)
-#'       ADCM$CMASTDTM <- ADCM$ASTDTM
-#'       ADCM$CMAENDTM <- ADCM$AENDTM
-#'     ",
-#'     join_keys = join_keys
-#'   ),
+#'   data = data,
 #'   modules = modules(
 #'     tm_g_pp_therapy(
 #'       label = "Therapy",
@@ -347,7 +366,9 @@ tm_g_pp_therapy <- function(label,
                             plot_width = NULL,
                             pre_output = NULL,
                             post_output = NULL,
-                            ggplot2_args = teal.widgets::ggplot2_args()) {
+                            ggplot2_args = teal.widgets::ggplot2_args(),
+                            transformators = list(),
+                            decorators = list()) {
   message("Initializing tm_g_pp_therapy")
   checkmate::assert_class(atirel, "choices_selected", null.ok = TRUE)
   checkmate::assert_class(cmdecod, "choices_selected", null.ok = TRUE)
@@ -375,6 +396,7 @@ tm_g_pp_therapy <- function(label,
   checkmate::assert_class(pre_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(post_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(ggplot2_args, "ggplot2_args")
+  assert_decorators(decorators, names = c("plot", "table"))
 
   args <- as.list(environment())
   data_extract_list <- list(
@@ -404,9 +426,11 @@ tm_g_pp_therapy <- function(label,
         patient_col = patient_col,
         plot_height = plot_height,
         plot_width = plot_width,
-        ggplot2_args = ggplot2_args
+        ggplot2_args = ggplot2_args,
+        decorators = decorators
       )
     ),
+    transformators = transformators,
     datanames = c(dataname, parentname)
   )
 }
@@ -510,6 +534,8 @@ ui_g_therapy <- function(id, ...) {
         data_extract_spec = ui_args$cmendy,
         is_single_dataset = is_single_dataset_value
       ),
+      ui_decorate_teal_data(ns("d_table"), decorators = select_decorators(ui_args$decorators, "table")),
+      ui_decorate_teal_data(ns("d_plot"), decorators = select_decorators(ui_args$decorators, "plot")),
       teal.widgets::panel_item(
         title = "Plot settings",
         collapsed = TRUE,
@@ -523,7 +549,6 @@ ui_g_therapy <- function(id, ...) {
       )
     ),
     forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
     pre_output = ui_args$pre_output,
@@ -552,13 +577,15 @@ srv_g_therapy <- function(id,
                           plot_height,
                           plot_width,
                           label,
-                          ggplot2_args) {
+                          ggplot2_args,
+                          decorators) {
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(isolate(data()), "teal_data")
 
   moduleServer(id, function(input, output, session) {
+    teal.logger::log_shiny_input_changes(input, namespace = "teal.modules.clinical")
     patient_id <- reactive(input$patient_id)
 
     # Init
@@ -666,23 +693,37 @@ srv_g_therapy <- function(id,
           )
         )
       ) %>%
-        teal.code::eval_code(as.expression(my_calls))
+        teal.code::eval_code(as.expression(unlist(my_calls)))
     })
 
     output$title <- renderText({
       paste("<h5><b>Patient ID:", all_q()[["pt_id"]], "</b></h5>")
     })
 
+    decorated_all_q_table <- srv_decorate_teal_data(
+      "d_table",
+      data = all_q,
+      decorators = select_decorators(decorators, "table"),
+      expr = table
+    )
+
     output$therapy_table <- DT::renderDataTable(
       expr = {
-        teal.code::dev_suppress(all_q()[["therapy_table"]])
+        teal.code::dev_suppress(decorated_all_q_table()[["table"]])
       },
       options = list(pageLength = input$therapy_table_rows)
     )
 
+    decorated_all_q_plot <- srv_decorate_teal_data(
+      "d_plot",
+      data = decorated_all_q_table,
+      decorators = select_decorators(decorators, "plot"),
+      expr = print(plot)
+    )
+
     plot_r <- reactive({
       req(iv_r()$is_valid())
-      all_q()[["therapy_plot"]]
+      decorated_all_q_plot()[["plot"]]
     })
 
     pws <- teal.widgets::plot_with_settings_srv(
@@ -692,16 +733,11 @@ srv_g_therapy <- function(id,
       width = plot_width
     )
 
-    teal.widgets::verbatim_popup_srv(
-      id = "warning",
-      verbatim_content = reactive(teal.code::get_warnings(all_q())),
-      title = "Warning",
-      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
-    )
-
+    # Render R code
+    source_code_r <- reactive(teal.code::get_code(req(decorated_all_q_plot())))
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = reactive(teal.code::get_code(all_q())),
+      verbatim_content = source_code_r,
       title = label
     )
 
@@ -715,14 +751,14 @@ srv_g_therapy <- function(id,
           filter_panel_api = filter_panel_api
         )
         card$append_text("Table", "header3")
-        card$append_table(teal.code::dev_suppress(all_q()[["therapy_table"]]))
+        card$append_table(teal.code::dev_suppress(all_q()[["table"]]))
         card$append_text("Plot", "header3")
         card$append_plot(plot_r(), dim = pws$dim())
         if (!comment == "") {
           card$append_text("Comment", "header3")
           card$append_text(comment)
         }
-        card$append_src(teal.code::get_code(all_q()))
+        card$append_src(source_code_r())
         card
       }
       teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
