@@ -120,6 +120,7 @@ template_abnormality <- function(parentname,
     teal.widgets::resolve_basic_table_args(
       user_table = basic_table_args,
       module_table = teal.widgets::basic_table_args(
+        show_colcounts = TRUE,
         title = tbl_title,
         main_footer = "Variables without observed abnormalities are excluded."
       )
@@ -137,8 +138,7 @@ template_abnormality <- function(parentname,
           rtables::split_cols_by(
             var = arm_var,
             split_fun = add_overall_level(total_label, first = FALSE)
-          ) %>%
-          rtables::add_colcounts(),
+          ),
         env = list(
           arm_var = arm_var,
           total_label = total_label,
@@ -148,8 +148,7 @@ template_abnormality <- function(parentname,
     } else {
       substitute(
         expr = expr_basic_table_args %>%
-          rtables::split_cols_by(var = arm_var) %>%
-          rtables::add_colcounts(),
+          rtables::split_cols_by(var = arm_var),
         env = list(arm_var = arm_var, expr_basic_table_args = parsed_basic_table_args)
       )
     }
@@ -212,9 +211,8 @@ template_abnormality <- function(parentname,
 
   y$table <- substitute(
     expr = {
-      result <- rtables::build_table(lyt = lyt, df = anl, alt_counts_df = parent) %>%
+      table <- rtables::build_table(lyt = lyt, df = anl, alt_counts_df = parent) %>%
         rtables::prune_table()
-      result
     },
     env = list(parent = as.name(parentname))
   )
@@ -227,6 +225,7 @@ template_abnormality <- function(parentname,
 #' This module produces a table to summarize abnormality.
 #'
 #' @inheritParams module_arguments
+#' @inheritParams teal::module
 #' @inheritParams template_abnormality
 #' @param grade ([teal.transform::choices_selected()])\cr
 #'   object with all available choices and preselected option for variable names that can be used to
@@ -238,15 +237,43 @@ template_abnormality <- function(parentname,
 #'
 #' @inherit module_arguments return seealso
 #'
+#' @section Decorating Module:
+#'
+#' This module generates the following objects, which can be modified in place using decorators:
+#' - `table` (`TableTree` - output of `rtables::build_table()`)
+#'
+#' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
+#' The name of this list corresponds to the name of the output to which the decorator is applied.
+#' See code snippet below:
+#'
+#' ```
+#' tm_t_abnormality(
+#'    ..., # arguments for module
+#'    decorators = list(
+#'      table = teal_transform_module(...) # applied only to `table` output
+#'    )
+#' )
+#' ```
+#'
+#' For additional details and examples of decorators, refer to the vignette
+#' `vignette("decorate-module-output", package = "teal.modules.clinical")`.
+#'
+#' To learn more please refer to the vignette
+#' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
+#'
 #' @note Patients with the same abnormality at baseline as on the treatment visit can be
 #'   excluded in accordance with GDSR specifications by using `exclude_base_abn`.
 #'
+#' @examplesShinylive
+#' library(teal.modules.clinical)
+#' interactive <- function() TRUE
+#' {{ next_example }}
+#'
 #' @examples
+#' library(dplyr)
 #'
 #' data <- teal_data()
 #' data <- within(data, {
-#'   library(dplyr)
-#'
 #'   ADSL <- tmc_ex_adsl
 #'   ADLB <- tmc_ex_adlb %>%
 #'     mutate(
@@ -256,9 +283,10 @@ template_abnormality <- function(parentname,
 #'       ) %>% with_label("On Treatment Record Flag")
 #'     )
 #' })
-#' datanames <- c("ADSL", "ADLB")
-#' datanames(data) <- datanames
-#' join_keys(data) <- default_cdisc_join_keys[datanames]
+#' join_keys(data) <- default_cdisc_join_keys[names(data)]
+#'
+#' ADSL <- data[["ADSL"]]
+#' ADLB <- data[["ADLB"]]
 #'
 #' app <- init(
 #'   data = data,
@@ -267,21 +295,21 @@ template_abnormality <- function(parentname,
 #'       label = "Abnormality Table",
 #'       dataname = "ADLB",
 #'       arm_var = choices_selected(
-#'         choices = variable_choices(data[["ADSL"]], subset = c("ARM", "ARMCD")),
+#'         choices = variable_choices(ADSL, subset = c("ARM", "ARMCD")),
 #'         selected = "ARM"
 #'       ),
 #'       add_total = FALSE,
 #'       by_vars = choices_selected(
-#'         choices = variable_choices(data[["ADLB"]], subset = c("LBCAT", "PARAM", "AVISIT")),
+#'         choices = variable_choices(ADLB, subset = c("LBCAT", "PARAM", "AVISIT")),
 #'         selected = c("LBCAT", "PARAM"),
 #'         keep_order = TRUE
 #'       ),
 #'       baseline_var = choices_selected(
-#'         variable_choices(data[["ADLB"]], subset = "BNRIND"),
+#'         variable_choices(ADLB, subset = "BNRIND"),
 #'         selected = "BNRIND", fixed = TRUE
 #'       ),
 #'       grade = choices_selected(
-#'         choices = variable_choices(data[["ADLB"]], subset = "ANRIND"),
+#'         choices = variable_choices(ADLB, subset = "ANRIND"),
 #'         selected = "ANRIND",
 #'         fixed = TRUE
 #'       ),
@@ -326,7 +354,9 @@ tm_t_abnormality <- function(label,
                              pre_output = NULL,
                              post_output = NULL,
                              na_level = default_na_str(),
-                             basic_table_args = teal.widgets::basic_table_args()) {
+                             basic_table_args = teal.widgets::basic_table_args(),
+                             transformators = list(),
+                             decorators = list()) {
   message("Initializing tm_t_abnormality")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
@@ -347,6 +377,7 @@ tm_t_abnormality <- function(label,
   checkmate::assert_class(pre_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(post_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(basic_table_args, "basic_table_args")
+  assert_decorators(decorators, "table")
 
   data_extract_list <- list(
     arm_var = cs_to_des_select(arm_var, dataname = parentname),
@@ -374,9 +405,11 @@ tm_t_abnormality <- function(label,
         label = label,
         total_label = total_label,
         na_level = na_level,
-        basic_table_args = basic_table_args
+        basic_table_args = basic_table_args,
+        decorators = decorators
       )
     ),
+    transformators = transformators,
     datanames = teal.transform::get_extract_datanames(data_extract_list)
   )
 }
@@ -430,6 +463,7 @@ ui_t_abnormality <- function(id, ...) {
         "Exclude subjects whose baseline grade is the same as abnormal grade",
         value = a$exclude_base_abn
       ),
+      ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "table")),
       teal.widgets::panel_group(
         teal.widgets::panel_item(
           "Additional table settings",
@@ -471,7 +505,6 @@ ui_t_abnormality <- function(id, ...) {
       )
     ),
     forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
     pre_output = a$pre_output,
@@ -499,13 +532,15 @@ srv_t_abnormality <- function(id,
                               drop_arm_levels,
                               label,
                               na_level,
-                              basic_table_args) {
+                              basic_table_args,
+                              decorators) {
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(isolate(data()), "teal_data")
 
   moduleServer(id, function(input, output, session) {
+    teal.logger::log_shiny_input_changes(input, namespace = "teal.modules.clinical")
     selector_list <- teal.transform::data_extract_multiple_srv(
       data_extract = list(
         arm_var = arm_var,
@@ -539,7 +574,7 @@ srv_t_abnormality <- function(id,
     )
 
     isolate({
-      resolved <- teal.transform::resolve_delayed(treatment_flag, as.list(data()@env))
+      resolved <- teal.transform::resolve_delayed(treatment_flag, as.list(data()))
       teal.widgets::updateOptionalSelectInput(
         session = session,
         inputId = "treatment_flag",
@@ -637,28 +672,29 @@ srv_t_abnormality <- function(id,
         tbl_title = tbl_title
       )
 
-      teal.code::eval_code(merged$anl_q(), as.expression(my_calls))
+      teal.code::eval_code(merged$anl_q(), as.expression(unlist(my_calls)))
     })
 
+    decorated_table_q <- srv_decorate_teal_data(
+      id = "decorator",
+      data = all_q,
+      decorators = select_decorators(decorators, "table"),
+      expr = table
+    )
+
     # Outputs to render.
-    table_r <- reactive(all_q()[["result"]])
+    table_r <- reactive(decorated_table_q()[["table"]])
 
     teal.widgets::table_with_settings_srv(
       id = "table",
       table_r = table_r
     )
 
-    teal.widgets::verbatim_popup_srv(
-      id = "warning",
-      verbatim_content = reactive(teal.code::get_warnings(all_q())),
-      title = "Warning",
-      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
-    )
-
     # Render R code.
+    source_code_r <- reactive(teal.code::get_code(req(decorated_table_q())))
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = reactive(teal.code::get_code(all_q())),
+      verbatim_content = source_code_r,
       title = label
     )
 
@@ -677,7 +713,7 @@ srv_t_abnormality <- function(id,
           card$append_text("Comment", "header3")
           card$append_text(comment)
         }
-        card$append_src(teal.code::get_code(all_q()))
+        card$append_src(source_code_r())
         card
       }
       teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
