@@ -186,14 +186,13 @@ template_logistic <- function(dataname,
 
   y$table <- substitute(
     expr = {
-      result <- expr_basic_table_args %>%
+      table <- expr_basic_table_args %>%
         summarize_logistic(
           conf_level = conf_level,
           drop_and_remove_str = "_NA_"
         ) %>%
         rtables::append_topleft(topleft) %>%
         rtables::build_table(df = mod)
-      result
     },
     env = list(
       expr_basic_table_args = parsed_basic_table_args,
@@ -211,6 +210,7 @@ template_logistic <- function(dataname,
 #' `LGRT02` available [here](https://insightsengineering.github.io/tlg-catalog/stable/tables/efficacy/lgrt02.html).
 #'
 #' @inheritParams module_arguments
+#' @inheritParams teal::module
 #' @inheritParams template_logistic
 #' @param arm_var ([teal.transform::choices_selected()] or `NULL`)\cr object
 #'   with all available choices and preselected option for variable names that can be used as `arm_var`. This defines
@@ -222,12 +222,48 @@ template_logistic <- function(dataname,
 #'
 #' @inherit module_arguments return seealso
 #'
+#' @section Decorating Module:
+#'
+#' This module generates the following objects, which can be modified in place using decorators:
+#' - `table` (`TableTree` - output of `rtables::build_table()`)
+#'
+#' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
+#' The name of this list corresponds to the name of the output to which the decorator is applied.
+#' See code snippet below:
+#'
+#' ```
+#' tm_t_logistic(
+#'    ..., # arguments for module
+#'    decorators = list(
+#'      table = teal_transform_module(...) # applied only to `table` output
+#'    )
+#' )
+#' ```
+#'
+#' For additional details and examples of decorators, refer to the vignette
+#' `vignette("decorate-module-output", package = "teal.modules.clinical")`.
+#'
+#' To learn more please refer to the vignette
+#' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
+#'
+#' @examplesShinylive
+#' library(teal.modules.clinical)
+#' interactive <- function() TRUE
+#' {{ next_example }}
+#'
 #' @examples
 #' library(dplyr)
 #'
-#' ADSL <- tmc_ex_adsl
-#' ADRS <- tmc_ex_adrs %>%
-#'   filter(PARAMCD %in% c("BESRSPI", "INVET"))
+#' data <- teal_data()
+#' data <- within(data, {
+#'   ADSL <- tmc_ex_adsl
+#'   ADRS <- tmc_ex_adrs %>%
+#'     filter(PARAMCD %in% c("BESRSPI", "INVET"))
+#' })
+#' join_keys(data) <- default_cdisc_join_keys[names(data)]
+#'
+#' ADSL <- data[["ADSL"]]
+#' ADRS <- data[["ADRS"]]
 #'
 #' arm_ref_comp <- list(
 #'   ACTARMCD = list(
@@ -241,15 +277,7 @@ template_logistic <- function(dataname,
 #' )
 #'
 #' app <- init(
-#'   data = cdisc_data(
-#'     ADSL = ADSL,
-#'     ADRS = ADRS,
-#'     code = "
-#'       ADSL <- tmc_ex_adsl
-#'       ADRS <- tmc_ex_adrs %>%
-#'         filter(PARAMCD %in% c(\"BESRSPI\", \"INVET\"))
-#'     "
-#'   ),
+#'   data = data,
 #'   modules = modules(
 #'     tm_t_logistic(
 #'       label = "Logistic Regression",
@@ -293,7 +321,9 @@ tm_t_logistic <- function(label,
                           conf_level = teal.transform::choices_selected(c(0.95, 0.9, 0.8), 0.95, keep_order = TRUE),
                           pre_output = NULL,
                           post_output = NULL,
-                          basic_table_args = teal.widgets::basic_table_args()) {
+                          basic_table_args = teal.widgets::basic_table_args(),
+                          transformators = list(),
+                          decorators = list()) {
   message("Initializing tm_t_logistic")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
@@ -307,6 +337,7 @@ tm_t_logistic <- function(label,
   checkmate::assert_class(pre_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(post_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(basic_table_args, "basic_table_args")
+  assert_decorators(decorators, "table")
 
   args <- as.list(environment())
 
@@ -329,9 +360,11 @@ tm_t_logistic <- function(label,
         label = label,
         dataname = dataname,
         parentname = parentname,
-        basic_table_args = basic_table_args
+        basic_table_args = basic_table_args,
+        decorators = decorators
       )
     ),
+    transformators = transformators,
     datanames = teal.transform::get_extract_datanames(data_extract_list)
   )
 }
@@ -420,10 +453,10 @@ ui_t_logistic <- function(id, ...) {
         a$conf_level$selected,
         multiple = FALSE,
         fixed = a$conf_level$fixed
-      )
+      ),
+      ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "table"))
     ),
     forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
     pre_output = a$pre_output,
@@ -444,13 +477,15 @@ srv_t_logistic <- function(id,
                            avalc_var,
                            cov_var,
                            label,
-                           basic_table_args) {
+                           basic_table_args,
+                           decorators) {
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
 
   moduleServer(id, function(input, output, session) {
+    teal.logger::log_shiny_input_changes(input, namespace = "teal.modules.clinical")
     # Observer to update reference and comparison arm input options.
     iv_arco <- arm_ref_comp_observer(
       session,
@@ -655,6 +690,7 @@ srv_t_logistic <- function(id,
       )
     })
 
+    # Generate r code for the analysis.
     all_q <- reactive({
       validate_checks()
 
@@ -692,23 +728,26 @@ srv_t_logistic <- function(id,
       teal.code::eval_code(merged$anl_q(), as.expression(calls))
     })
 
-    table_r <- reactive(all_q()[["result"]])
+    # Decoration of table output.
+    decorated_table_q <- srv_decorate_teal_data(
+      id = "decorator",
+      data = all_q,
+      decorators = select_decorators(decorators, "table"),
+      expr = table
+    )
+
+    table_r <- reactive(decorated_table_q()[["table"]])
 
     teal.widgets::table_with_settings_srv(
       id = "table",
       table_r = table_r
     )
 
-    teal.widgets::verbatim_popup_srv(
-      id = "warning",
-      verbatim_content = reactive(teal.code::get_warnings(all_q())),
-      title = "Warning",
-      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
-    )
-
+    # Render R code.
+    source_code_r <- reactive(teal.code::get_code(req(decorated_table_q())))
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = reactive(teal.code::get_code(all_q())),
+      verbatim_content = source_code_r,
       title = label
     )
 
@@ -727,7 +766,7 @@ srv_t_logistic <- function(id,
           card$append_text("Comment", "header3")
           card$append_text(comment)
         }
-        card$append_src(teal.code::get_code(all_q()))
+        card$append_src(source_code_r())
         card
       }
       teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
