@@ -100,7 +100,8 @@ template_mult_events <- function(dataname,
 
   parsed_basic_table_args <- teal.widgets::parse_basic_table_args(
     teal.widgets::resolve_basic_table_args(
-      user_table = basic_table_args
+      user_table = basic_table_args,
+      module_table = teal.widgets::basic_table_args(show_colcounts = TRUE)
     )
   )
 
@@ -111,8 +112,7 @@ template_mult_events <- function(dataname,
   layout_list <- add_expr(
     layout_list,
     substitute(
-      expr = rtables::split_cols_by(var = arm_var) %>%
-        rtables::add_colcounts(),
+      expr = rtables::split_cols_by(var = arm_var),
       env = list(arm_var = arm_var)
     )
   )
@@ -263,8 +263,7 @@ template_mult_events <- function(dataname,
   # Combine tables.
   y$final_table <- quote(
     expr = {
-      result <- sorted_result
-      result
+      table <- sorted_result
     }
   )
 
@@ -276,31 +275,60 @@ template_mult_events <- function(dataname,
 #' This module produces a table of multiple events by term.
 #'
 #' @inheritParams module_arguments
+#' @inheritParams teal::module
 #' @inheritParams template_mult_events
 #' @param seq_var ([teal.transform::choices_selected()])\cr object with
 #'   all available choices and preselected option for variable names that can be used as analysis sequence number
 #'   variable. Used for counting the unique number of events.
+#' @param title_text (`string`)\cr text to display as the first part of the dynamic table title. The table title is
+#'   constructed as follows: "`title_text` by `hlt` and `llt`". Defaults to `"Concomitant Medications"`.
 #'
 #' @inherit module_arguments return seealso
 #'
-#' @examples
-#' ADSL <- tmc_ex_adsl
-#' ADCM <- tmc_ex_adcm
-#' adcm_keys <- c("STUDYID", "USUBJID", "ASTDTM", "CMSEQ", "ATC1", "ATC2", "ATC3", "ATC4")
+#' @section Decorating Module:
 #'
-#' join_keys <- default_cdisc_join_keys[c("ADSL", "ADCM")]
-#' join_keys["ADCM", "ADCM"] <- adcm_keys
+#' This module generates the following objects, which can be modified in place using decorators:
+#' - `table` (`TableTree` - output of `rtables::build_table()`)
+#'
+#' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
+#' The name of this list corresponds to the name of the output to which the decorator is applied.
+#' See code snippet below:
+#'
+#' ```
+#' tm_t_mult_events(
+#'    ..., # arguments for module
+#'    decorators = list(
+#'      table = teal_transform_module(...) # applied only to `table` output
+#'    )
+#' )
+#' ```
+#'
+#' For additional details and examples of decorators, refer to the vignette
+#' `vignette("decorate-module-output", package = "teal.modules.clinical")`.
+#'
+#' To learn more please refer to the vignette
+#' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
+#'
+#' @examplesShinylive
+#' library(teal.modules.clinical)
+#' interactive <- function() TRUE
+#' {{ next_example }}
+#'
+#' @examples
+#' data <- teal_data()
+#' data <- within(data, {
+#'   ADSL <- tmc_ex_adsl
+#'   ADCM <- tmc_ex_adcm
+#' })
+#' join_keys(data) <- default_cdisc_join_keys[names(data)]
+#' adcm_keys <- c("STUDYID", "USUBJID", "ASTDTM", "CMSEQ", "ATC1", "ATC2", "ATC3", "ATC4")
+#' join_keys(data)["ADCM", "ADCM"] <- adcm_keys
+#'
+#' ADSL <- data[["ADSL"]]
+#' ADCM <- data[["ADCM"]]
 #'
 #' app <- init(
-#'   data = cdisc_data(
-#'     ADSL = ADSL,
-#'     ADCM = ADCM,
-#'     code = "
-#'       ADSL <- tmc_ex_adsl
-#'       ADCM <- tmc_ex_adcm
-#'     ",
-#'     join_keys = join_keys
-#'   ),
+#'   data = data,
 #'   modules = modules(
 #'     tm_t_mult_events(
 #'       label = "Concomitant Medications by Medication Class and Preferred Name",
@@ -340,10 +368,13 @@ tm_t_mult_events <- function(label,
                              total_label = default_total_label(),
                              na_level = default_na_str(),
                              event_type = "event",
+                             title_text = "Concomitant Medications",
                              drop_arm_levels = TRUE,
                              pre_output = NULL,
                              post_output = NULL,
-                             basic_table_args = teal.widgets::basic_table_args()) {
+                             basic_table_args = teal.widgets::basic_table_args(),
+                             transformators = list(),
+                             decorators = list()) {
   message("Initializing tm_t_mult_events")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
@@ -353,6 +384,7 @@ tm_t_mult_events <- function(label,
   checkmate::assert_class(hlt, "choices_selected")
   checkmate::assert_class(llt, "choices_selected")
   checkmate::assert_string(event_type)
+  checkmate::assert_string(title_text)
   checkmate::assert_flag(add_total)
   checkmate::assert_string(total_label)
   checkmate::assert_string(na_level)
@@ -360,6 +392,7 @@ tm_t_mult_events <- function(label,
   checkmate::assert_class(pre_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(post_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(basic_table_args, "basic_table_args")
+  assert_decorators(decorators, "table")
 
   args <- as.list(environment())
 
@@ -381,12 +414,15 @@ tm_t_mult_events <- function(label,
         dataname = dataname,
         parentname = parentname,
         event_type = event_type,
+        title_text = title_text,
         label = label,
         total_label = total_label,
         na_level = na_level,
-        basic_table_args = basic_table_args
+        basic_table_args = basic_table_args,
+        decorators = decorators
       )
     ),
+    transformators = transformators,
     datanames = teal.transform::get_extract_datanames(data_extract_list)
   )
 }
@@ -436,6 +472,7 @@ ui_t_mult_events_byterm <- function(id, ...) {
           )
         )
       ),
+      ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "table")),
       teal.widgets::panel_group(
         teal.widgets::panel_item(
           "Additional Variables Info",
@@ -449,7 +486,6 @@ ui_t_mult_events_byterm <- function(id, ...) {
       )
     ),
     forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
     pre_output = a$pre_output,
@@ -465,6 +501,7 @@ srv_t_mult_events_byterm <- function(id,
                                      dataname,
                                      parentname,
                                      event_type,
+                                     title_text,
                                      arm_var,
                                      seq_var,
                                      hlt,
@@ -473,13 +510,15 @@ srv_t_mult_events_byterm <- function(id,
                                      label,
                                      total_label,
                                      na_level,
-                                     basic_table_args) {
+                                     basic_table_args,
+                                     decorators) {
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
 
   moduleServer(id, function(input, output, session) {
+    teal.logger::log_shiny_input_changes(input, namespace = "teal.modules.clinical")
     selector_list <- teal.transform::data_extract_multiple_srv(
       data_extract = list(
         arm_var = arm_var,
@@ -564,12 +603,7 @@ srv_t_mult_events_byterm <- function(id,
 
       basic_table_args$title <- ifelse(
         is.null(basic_table_args$title),
-        paste(
-          "Concomitant Medications by",
-          paste(hlt_labels, collapse = ", "),
-          "and",
-          paste(llt_labels, collapse = ", ")
-        ),
+        paste(title_text, "by", paste(hlt_labels, collapse = ", "), "and", paste(llt_labels, collapse = ", ")),
         basic_table_args$title
       )
 
@@ -587,25 +621,26 @@ srv_t_mult_events_byterm <- function(id,
         drop_arm_levels = input$drop_arm_levels,
         basic_table_args = basic_table_args
       )
-      teal.code::eval_code(anl_q, as.expression(my_calls))
+      teal.code::eval_code(anl_q, as.expression(unlist(my_calls)))
     })
 
+    decorated_table_q <- srv_decorate_teal_data(
+      id = "decorator",
+      data = all_q,
+      decorators = select_decorators(decorators, "table"),
+      expr = table
+    )
+
     # Outputs to render.
-    table_r <- reactive(all_q()[["result"]])
+    table_r <- reactive(decorated_table_q()[["table"]])
 
     teal.widgets::table_with_settings_srv(id = "table", table_r = table_r)
 
-    teal.widgets::verbatim_popup_srv(
-      id = "warning",
-      verbatim_content = reactive(teal.code::get_warnings(all_q())),
-      title = "Warning",
-      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
-    )
-
     # Render R code.
+    source_code_r <- reactive(teal.code::get_code(req(decorated_table_q())))
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = reactive(teal.code::get_code(all_q())),
+      verbatim_content = source_code_r,
       title = label
     )
 
@@ -624,7 +659,7 @@ srv_t_mult_events_byterm <- function(id,
           card$append_text("Comment", "header3")
           card$append_text(comment)
         }
-        card$append_src(teal.code::get_code(all_q()))
+        card$append_src(source_code_r())
         card
       }
       teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
