@@ -70,7 +70,7 @@ template_laboratory <- function(dataname = "ANL",
           dplyr::mutate(aval_anrind = paste(aval_var, anrind)) %>%
           dplyr::select(-c(aval_var, anrind))
 
-        labor_table_raw <- labor_table_base %>%
+        result <- labor_table_base %>%
           as.data.frame() %>%
           stats::reshape(
             direction = "wide",
@@ -78,18 +78,18 @@ template_laboratory <- function(dataname = "ANL",
             v.names = "aval_anrind",
             timevar = "INDEX"
           )
-        colnames(labor_table_raw)[-c(1:3)] <- unique(labor_table_base$INDEX)
+        colnames(result)[-c(1:3)] <- unique(labor_table_base$INDEX)
 
-        labor_table_raw[[param_char]] <- clean_description(labor_table_raw[[param_char]])
+        result[[param_char]] <- clean_description(result[[param_char]])
 
-        labor_table_raw <- rlistings::as_listing(
-          labor_table_raw,
+        table_listing <- rlistings::as_listing(
+          result,
           key_cols = NULL,
           default_formatting = list(all = fmt_config(align = "left"))
         )
-        main_title(labor_table_raw) <- paste("Patient ID:", patient_id)
+        main_title(table_listing) <- paste("Patient ID:", patient_id)
 
-        labor_table_html <- labor_table_base %>%
+        table <- labor_table_base %>%
           dplyr::mutate(aval_anrind_col = color_lab_values(aval_anrind)) %>%
           dplyr::select(-aval_anrind) %>%
           as.data.frame() %>%
@@ -99,15 +99,21 @@ template_laboratory <- function(dataname = "ANL",
             v.names = "aval_anrind_col",
             timevar = "INDEX"
           )
-        colnames(labor_table_html)[-c(1:3)] <- unique(labor_table_base$INDEX)
-        labor_table_html[[param_char]] <- clean_description(labor_table_html[[param_char]])
+        colnames(table)[-c(1:3)] <- unique(labor_table_base$INDEX)
+        table[[param_char]] <- clean_description(table[[param_char]])
 
-        labor_table_html_dt <- DT::datatable(labor_table_html, escape = FALSE)
-        labor_table_html_dt$dependencies <- c(
-          labor_table_html_dt$dependencies,
+        table <- DT::datatable(
+          table,
+          escape = FALSE,
+          options = list(
+            lengthMenu = list(list(-1, 5, 10, 25), list("All", "5", "10", "25")),
+            scrollX = TRUE
+          )
+        )
+        table$dependencies <- c(
+          table$dependencies,
           list(rmarkdown::html_dependency_bootstrap("default"))
         )
-        labor_table_html_dt
       },
       env = list(
         dataname = as.name(dataname),
@@ -136,6 +142,7 @@ template_laboratory <- function(dataname = "ANL",
 #' This module produces a patient profile laboratory table using ADaM datasets.
 #'
 #' @inheritParams module_arguments
+#' @inheritParams teal::module
 #' @inheritParams template_laboratory
 #' @param param ([teal.transform::choices_selected()])\cr object with all
 #'   available choices and preselected option for the `PARAM` variable from `dataname`.
@@ -147,19 +154,48 @@ template_laboratory <- function(dataname = "ANL",
 #'
 #' @inherit module_arguments return
 #'
+#' @section Decorating Module:
+#'
+#' This module generates the following objects, which can be modified in place using decorators:
+#' - `table` (`datatables` - output of `DT::datatable()`)
+#'
+#' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
+#' The name of this list corresponds to the name of the output to which the decorator is applied.
+#' See code snippet below:
+#'
+#' ```
+#' tm_t_pp_laboratory(
+#'    ..., # arguments for module
+#'    decorators = list(
+#'      table = teal_transform_module(...) # applied only to `table` output
+#'    )
+#' )
+#' ```
+#'
+#' For additional details and examples of decorators, refer to the vignette
+#' `vignette("decorate-module-output", package = "teal.modules.clinical")`.
+#'
+#' To learn more please refer to the vignette
+#' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
+#'
+#' @examplesShinylive
+#' library(teal.modules.clinical)
+#' interactive <- function() TRUE
+#' {{ next_example }}
+#'
 #' @examples
-#' ADSL <- tmc_ex_adsl
-#' ADLB <- tmc_ex_adlb
+#' data <- teal_data()
+#' data <- within(data, {
+#'   ADSL <- tmc_ex_adsl
+#'   ADLB <- tmc_ex_adlb
+#' })
+#' join_keys(data) <- default_cdisc_join_keys[names(data)]
+#'
+#' ADSL <- data[["ADSL"]]
+#' ADLB <- data[["ADLB"]]
 #'
 #' app <- init(
-#'   data = cdisc_data(
-#'     ADSL = ADSL,
-#'     ADLB = ADLB,
-#'     code = "
-#'       ADSL <- tmc_ex_adsl
-#'       ADLB <- tmc_ex_adlb
-#'     "
-#'   ),
+#'   data = data,
 #'   modules = modules(
 #'     tm_t_pp_laboratory(
 #'       label = "Vitals",
@@ -210,7 +246,9 @@ tm_t_pp_laboratory <- function(label,
                                paramcd = NULL,
                                anrind = NULL,
                                pre_output = NULL,
-                               post_output = NULL) {
+                               post_output = NULL,
+                               transformators = list(),
+                               decorators = list()) {
   if (lifecycle::is_present(aval)) {
     aval_var <- aval
     warning(
@@ -246,6 +284,7 @@ tm_t_pp_laboratory <- function(label,
   checkmate::assert_class(anrind, "choices_selected", null.ok = TRUE)
   checkmate::assert_class(pre_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(post_output, classes = "shiny.tag", null.ok = TRUE)
+  assert_decorators(decorators, "table")
 
   args <- as.list(environment())
   data_extract_list <- list(
@@ -268,9 +307,11 @@ tm_t_pp_laboratory <- function(label,
         dataname = dataname,
         parentname = parentname,
         label = label,
-        patient_col = patient_col
+        patient_col = patient_col,
+        decorators = decorators
       )
     ),
+    transformators = transformators,
     datanames = c(dataname, parentname)
   )
 }
@@ -345,10 +386,10 @@ ui_g_laboratory <- function(id, ...) {
         inputId = ns("round_value"),
         label = "Select number of decimal places for rounding:",
         choices = NULL
-      )
+      ),
+      ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(ui_args$decorators, "table"))
     ),
     forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
     pre_output = ui_args$pre_output,
@@ -370,13 +411,15 @@ srv_g_laboratory <- function(id,
                              param,
                              paramcd,
                              anrind,
-                             label) {
+                             label,
+                             decorators) {
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
 
   moduleServer(id, function(input, output, session) {
+    teal.logger::log_shiny_input_changes(input, namespace = "teal.modules.clinical")
     patient_id <- reactive(input$patient_id)
 
     # Init
@@ -453,6 +496,7 @@ srv_g_laboratory <- function(id,
         teal.code::eval_code(as.expression(anl_inputs()$expr))
     })
 
+    # Generate r code for the analysis.
     all_q <- reactive({
       teal::validate_inputs(iv_r())
 
@@ -483,37 +527,35 @@ srv_g_laboratory <- function(id,
         teal.code::eval_code(as.expression(labor_calls))
     })
 
-    output$title <- renderText({
-      paste("<h5><b>Patient ID:", all_q()[["pt_id"]], "</b></h5>")
-    })
+    # Decoration of raw table output.
+    decorated_table_q <- srv_decorate_teal_data(
+      id = "decorator",
+      data = all_q,
+      decorators = select_decorators(decorators, "table"),
+      expr = table
+    )
 
+    # Outputs to render.
     table_r <- reactive({
-      q <- all_q()
+      q <- decorated_table_q()
       list(
-        html = q[["labor_table_html"]],
-        raw = q[["labor_table_raw"]]
+        html = q[["table"]],
+        listing = q[["table_listing"]]
       )
     })
 
-    output$lab_values_table <- DT::renderDataTable(
-      expr = table_r()$html,
-      escape = FALSE,
-      options = list(
-        lengthMenu = list(list(-1, 5, 10, 25), list("All", "5", "10", "25")),
-        scrollX = TRUE
-      )
-    )
+    output$title <- renderText({
+      req(decorated_table_q())
+      paste("<h5><b>Patient ID:", decorated_table_q()[["pt_id"]], "</b></h5>")
+    })
 
-    teal.widgets::verbatim_popup_srv(
-      id = "warning",
-      verbatim_content = reactive(teal.code::get_warnings(all_q())),
-      title = "Warning",
-      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
-    )
+    output$lab_values_table <- DT::renderDataTable(expr = table_r()$html)
 
+    # Render R code.
+    source_code_r <- reactive(teal.code::get_code(req(decorated_table_q())))
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = reactive(teal.code::get_code(all_q())),
+      verbatim_content = source_code_r,
       title = label
     )
 
@@ -527,12 +569,12 @@ srv_g_laboratory <- function(id,
           filter_panel_api = filter_panel_api
         )
         card$append_text("Table", "header3")
-        card$append_table(table_r()$raw)
+        card$append_table(table_r()$listing)
         if (!comment == "") {
           card$append_text("Comment", "header3")
           card$append_text(comment)
         }
-        card$append_src(teal.code::get_code(all_q()))
+        card$append_src(source_code_r())
         card
       }
       teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
