@@ -40,7 +40,7 @@ template_medical_history <- function(dataname = "ANL",
         dplyr::distinct() %>%
         `colnames<-`(labels)
 
-      result <- rtables::basic_table() %>%
+      table <- rtables::basic_table() %>%
         rtables::split_cols_by_multivar(colnames(result_raw)[2:3]) %>%
         rtables::split_rows_by(
           colnames(result_raw)[1],
@@ -54,9 +54,7 @@ template_medical_history <- function(dataname = "ANL",
         rtables::analyze_colvars(function(x) x[seq_along(x)]) %>%
         rtables::build_table(result_raw)
 
-      main_title(result) <- paste("Patient ID:", patient_id)
-
-      result
+      main_title(table) <- paste("Patient ID:", patient_id)
     }, env = list(
       dataname = as.name(dataname),
       mhbodsys = as.name(mhbodsys),
@@ -79,6 +77,7 @@ template_medical_history <- function(dataname = "ANL",
 #' This module produces a patient profile medical history report using ADaM datasets.
 #'
 #' @inheritParams module_arguments
+#' @inheritParams teal::module
 #' @inheritParams template_medical_history
 #' @param mhterm ([teal.transform::choices_selected()])\cr object with all
 #'   available choices and preselected option for the `MHTERM` variable from `dataname`.
@@ -88,20 +87,48 @@ template_medical_history <- function(dataname = "ANL",
 #'   available choices and preselected option for the `MHDISTAT` variable from `dataname`.
 #'
 #' @inherit module_arguments return
+#' @section Decorating Module:
+#'
+#' This module generates the following objects, which can be modified in place using decorators:
+#' - `table` (`TableTree` - output of `rtables::build_table()`)
+#'
+#' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
+#' The name of this list corresponds to the name of the output to which the decorator is applied.
+#' See code snippet below:
+#'
+#' ```
+#' tm_t_pp_medical_history(
+#'    ..., # arguments for module
+#'    decorators = list(
+#'      table = teal_transform_module(...) # applied only to `table` output
+#'    )
+#' )
+#' ```
+#'
+#' For additional details and examples of decorators, refer to the vignette
+#' `vignette("decorate-module-output", package = "teal.modules.clinical")`.
+#'
+#' To learn more please refer to the vignette
+#' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
+#'
+#' @examplesShinylive
+#' library(teal.modules.clinical)
+#' interactive <- function() TRUE
+#' {{ next_example }}
 #'
 #' @examples
-#' ADSL <- tmc_ex_adsl
-#' ADMH <- tmc_ex_admh
+#' data <- teal_data()
+#' data <- within(data, {
+#'   ADSL <- tmc_ex_adsl
+#'   ADMH <- tmc_ex_admh
+#' })
+#' join_keys(data) <- default_cdisc_join_keys[names(data)]
+#'
+#' ADSL <- data[["ADSL"]]
+#' ADMH <- data[["ADMH"]]
 #'
 #' app <- init(
-#'   data = cdisc_data(
-#'     ADSL = ADSL,
-#'     ADMH = ADMH,
-#'     code = "
-#'       ADSL <- tmc_ex_adsl
-#'       ADMH <- tmc_ex_admh
-#'     "
-#'   ),
+#'   data = data,
 #'   modules = modules(
 #'     tm_t_pp_medical_history(
 #'       label = "Medical History",
@@ -136,7 +163,9 @@ tm_t_pp_medical_history <- function(label,
                                     mhbodsys = NULL,
                                     mhdistat = NULL,
                                     pre_output = NULL,
-                                    post_output = NULL) {
+                                    post_output = NULL,
+                                    transformators = list(),
+                                    decorators = list()) {
   message("Initializing tm_t_pp_medical_history")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
@@ -147,6 +176,7 @@ tm_t_pp_medical_history <- function(label,
   checkmate::assert_class(mhdistat, "choices_selected", null.ok = TRUE)
   checkmate::assert_class(pre_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(post_output, classes = "shiny.tag", null.ok = TRUE)
+  assert_decorators(decorators, "table")
 
   args <- as.list(environment())
   data_extract_list <- list(
@@ -166,9 +196,11 @@ tm_t_pp_medical_history <- function(label,
         dataname = dataname,
         parentname = parentname,
         label = label,
-        patient_col = patient_col
+        patient_col = patient_col,
+        decorators = decorators
       )
     ),
+    transformators = transformators,
     datanames = c(dataname, parentname)
   )
 }
@@ -216,10 +248,10 @@ ui_t_medical_history <- function(id, ...) {
         label = "Select MHDISTAT variable:",
         data_extract_spec = ui_args$mhdistat,
         is_single_dataset = is_single_dataset_value
-      )
+      ),
+      ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(ui_args$decorators, "table"))
     ),
     forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
     pre_output = ui_args$pre_output,
@@ -238,13 +270,15 @@ srv_t_medical_history <- function(id,
                                   mhterm,
                                   mhbodsys,
                                   mhdistat,
-                                  label) {
+                                  label,
+                                  decorators) {
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
 
   moduleServer(id, function(input, output, session) {
+    teal.logger::log_shiny_input_changes(input, namespace = "teal.modules.clinical")
     patient_id <- reactive(input$patient_id)
 
     # Init
@@ -298,6 +332,7 @@ srv_t_medical_history <- function(id,
         teal.code::eval_code(as.expression(anl_inputs()$expr))
     })
 
+    # Generate r code for the analysis.
     all_q <- reactive({
       teal::validate_inputs(iv_r())
 
@@ -327,26 +362,30 @@ srv_t_medical_history <- function(id,
           )
         )
       ) %>%
-        teal.code::eval_code(as.expression(my_calls))
+        teal.code::eval_code(as.expression(unlist(my_calls)))
     })
 
-    table_r <- reactive(all_q()[["result"]])
+    # Decoration of table output.
+    decorated_table_q <- srv_decorate_teal_data(
+      id = "decorator",
+      data = all_q,
+      decorators = select_decorators(decorators, "table"),
+      expr = table
+    )
+
+    # Outputs to render.
+    table_r <- reactive(decorated_table_q()[["table"]])
 
     teal.widgets::table_with_settings_srv(
       id = "table",
       table_r = table_r
     )
 
-    teal.widgets::verbatim_popup_srv(
-      id = "warning",
-      verbatim_content = reactive(teal.code::get_warnings(all_q())),
-      title = "Warning",
-      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
-    )
-
+    # Render R code.
+    source_code_r <- reactive(teal.code::get_code(req(decorated_table_q())))
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = reactive(teal.code::get_code(all_q())),
+      verbatim_content = source_code_r,
       title = label
     )
 
@@ -365,7 +404,7 @@ srv_t_medical_history <- function(id,
           card$append_text("Comment", "header3")
           card$append_text(comment)
         }
-        card$append_src(teal.code::get_code(all_q()))
+        card$append_src(source_code_r())
         card
       }
       teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
