@@ -135,7 +135,8 @@ template_smq <- function(dataname,
 
   parsed_basic_table_args <- teal.widgets::parse_basic_table_args(
     teal.widgets::resolve_basic_table_args(
-      user_table = basic_table_args
+      user_table = basic_table_args,
+      module_table = teal.widgets::basic_table_args(show_colcounts = TRUE)
     )
   )
 
@@ -167,11 +168,6 @@ template_smq <- function(dataname,
     )
   }
 
-  layout_list <- add_expr(
-    layout_list,
-    quote(rtables::add_colcounts())
-  )
-
   if (add_total) {
     layout_list <- add_expr(
       layout_list,
@@ -294,8 +290,7 @@ template_smq <- function(dataname,
       all_zero <- function(tr) {
         !inherits(tr, "ContentRow") && rtables::all_zero_or_na(tr)
       }
-      pruned_and_sorted_result <- sorted_result %>% rtables::trim_rows(criteria = all_zero)
-      pruned_and_sorted_result
+      table <- sorted_result %>% rtables::trim_rows(criteria = all_zero)
     }
   )
 
@@ -307,7 +302,13 @@ template_smq <- function(dataname,
 #' This module produces an adverse events table by Standardized MedDRA Query.
 #'
 #' @inheritParams module_arguments
+#' @inheritParams teal::module
 #' @inheritParams template_smq
+#' @param arm_var ([teal.transform::choices_selected()])\cr object with all
+#'   available choices and preselected option for variable names that can be used as `arm_var`.
+#'   It defines the grouping variable(s) in the results table.
+#'   If there are two elements selected for `arm_var`,
+#'   second variable will be nested under the first variable.
 #' @param baskets ([teal.transform::choices_selected()])\cr object with all
 #'   available choices and preselected options for standardized/customized queries.
 #' @param scopes ([teal.transform::choices_selected()])\cr object with all
@@ -315,30 +316,56 @@ template_smq <- function(dataname,
 #'
 #' @inherit module_arguments return seealso
 #'
+#' @section Decorating Module:
+#'
+#' This module generates the following objects, which can be modified in place using decorators:
+#' - `table` (`TableTree` - output of `rtables::build_table()`)
+#'
+#' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
+#' The name of this list corresponds to the name of the output to which the decorator is applied.
+#' See code snippet below:
+#'
+#' ```
+#' tm_t_smq(
+#'    ..., # arguments for module
+#'    decorators = list(
+#'      table = teal_transform_module(...) # applied only to `table` output
+#'    )
+#' )
+#' ```
+#'
+#' For additional details and examples of decorators, refer to the vignette
+#' `vignette("decorate-module-output", package = "teal.modules.clinical")`.
+#'
+#' To learn more please refer to the vignette
+#' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
+#'
+#' @examplesShinylive
+#' library(teal.modules.clinical)
+#' interactive <- function() TRUE
+#' {{ next_example }}
+#'
 #' @examples
 #' data <- teal_data()
 #' data <- within(data, {
 #'   ADSL <- tmc_ex_adsl
 #'   ADAE <- tmc_ex_adae
 #'
-#'   names_baskets <- grep("^(SMQ|CQ).*NAM$", names(ADAE), value = TRUE)
-#'   names_scopes <- grep("^SMQ.*SC$", names(ADAE), value = TRUE)
+#'   .names_baskets <- grep("^(SMQ|CQ).*NAM$", names(ADAE), value = TRUE)
+#'   .names_scopes <- grep("^SMQ.*SC$", names(ADAE), value = TRUE)
 #'
-#'   cs_baskets <- choices_selected(
-#'     choices = variable_choices(ADAE, subset = names_baskets),
-#'     selected = names_baskets
+#'   .cs_baskets <- choices_selected(
+#'     choices = variable_choices(ADAE, subset = .names_baskets),
+#'     selected = .names_baskets
 #'   )
 #'
-#'   cs_scopes <- choices_selected(
-#'     choices = variable_choices(ADAE, subset = names_scopes),
-#'     selected = names_scopes,
+#'   .cs_scopes <- choices_selected(
+#'     choices = variable_choices(ADAE, subset = .names_scopes),
+#'     selected = .names_scopes,
 #'     fixed = TRUE
 #'   )
 #' })
-#'
-#' datanames <- c("ADSL", "ADAE")
-#' datanames(data) <- datanames
-#' join_keys(data) <- default_cdisc_join_keys[datanames]
+#' join_keys(data) <- default_cdisc_join_keys[names(data)]
 #'
 #' app <- init(
 #'   data = data,
@@ -351,8 +378,8 @@ template_smq <- function(dataname,
 #'         selected = "ARM"
 #'       ),
 #'       add_total = FALSE,
-#'       baskets = data[["cs_baskets"]],
-#'       scopes = data[["cs_scopes"]],
+#'       baskets = data[[".cs_baskets"]],
+#'       scopes = data[[".cs_scopes"]],
 #'       llt = choices_selected(
 #'         choices = variable_choices(data[["ADAE"]], subset = c("AEDECOD")),
 #'         selected = "AEDECOD"
@@ -388,7 +415,9 @@ tm_t_smq <- function(label,
                      scopes,
                      pre_output = NULL,
                      post_output = NULL,
-                     basic_table_args = teal.widgets::basic_table_args()) {
+                     basic_table_args = teal.widgets::basic_table_args(),
+                     transformators = list(),
+                     decorators = list()) {
   message("Initializing tm_t_smq")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
@@ -405,6 +434,7 @@ tm_t_smq <- function(label,
   checkmate::assert_class(pre_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(post_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(basic_table_args, "basic_table_args")
+  assert_decorators(decorators, "table")
 
   args <- as.list(environment())
 
@@ -429,9 +459,11 @@ tm_t_smq <- function(label,
         na_level = na_level,
         label = label,
         total_label = total_label,
-        basic_table_args = basic_table_args
+        basic_table_args = basic_table_args,
+        decorators = decorators
       )
     ),
+    transformators = transformators,
     datanames = teal.transform::get_extract_datanames(data_extract_list)
   )
 }
@@ -441,7 +473,6 @@ ui_t_smq <- function(id, ...) {
   ns <- NS(id)
   a <- list(...) # module args
 
-
   is_single_dataset_value <- teal.transform::is_single_dataset(
     a$arm_var,
     a$id_var,
@@ -479,6 +510,7 @@ ui_t_smq <- function(id, ...) {
         data_extract_spec = a$baskets,
         is_single_dataset = is_single_dataset_value
       ),
+      ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "table")),
       teal.widgets::panel_group(
         teal.widgets::panel_item(
           "Additional Variables Info",
@@ -515,7 +547,6 @@ ui_t_smq <- function(id, ...) {
       )
     ),
     forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
     pre_output = a$pre_output,
@@ -538,12 +569,14 @@ srv_t_smq <- function(id,
                       na_level,
                       label,
                       total_label,
-                      basic_table_args) {
+                      basic_table_args,
+                      decorators) {
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
   moduleServer(id, function(input, output, session) {
+    teal.logger::log_shiny_input_changes(input, namespace = "teal.modules.clinical")
     selector_list <- teal.transform::data_extract_multiple_srv(
       data_extract = list(
         scopes = scopes,
@@ -618,6 +651,7 @@ srv_t_smq <- function(id,
       )
     })
 
+    # Generate r code for the analysis.
     all_q <- reactive({
       validate_checks()
 
@@ -636,28 +670,30 @@ srv_t_smq <- function(id,
         basic_table_args = basic_table_args
       )
 
-      teal.code::eval_code(merged$anl_q(), as.expression(my_calls))
+      teal.code::eval_code(merged$anl_q(), as.expression(unlist(my_calls)))
     })
 
+    # Decoration of table output.
+    decorated_table_q <- srv_decorate_teal_data(
+      id = "decorator",
+      data = all_q,
+      decorators = select_decorators(decorators, "table"),
+      expr = table
+    )
+
     # Outputs to render.
-    table_r <- reactive(all_q()[["pruned_and_sorted_result"]])
+    table_r <- reactive(decorated_table_q()[["table"]])
 
     teal.widgets::table_with_settings_srv(
       id = "table",
       table_r = table_r
     )
 
-    teal.widgets::verbatim_popup_srv(
-      id = "warning",
-      verbatim_content = reactive(teal.code::get_warnings(all_q())),
-      title = "Warning",
-      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
-    )
-
     # Render R code.
+    source_code_r <- reactive(teal.code::get_code(req(decorated_table_q())))
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = reactive(teal.code::get_code(all_q())),
+      verbatim_content = source_code_r,
       title = label
     )
 
@@ -676,7 +712,7 @@ srv_t_smq <- function(id,
           card$append_text("Comment", "header3")
           card$append_text(comment)
         }
-        card$append_src(teal.code::get_code(all_q()))
+        card$append_src(source_code_r())
         card
       }
       teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
